@@ -19,17 +19,15 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Cambridge, MA 02110-1301, USA
 
 */
 // Self
-#include "fullscreencontent.moc"
+#include "fullscreencontent.h"
 
 // Qt
 #include <QAction>
 #include <QApplication>
 #include <QCheckBox>
 #include <QEvent>
-#include <QGridLayout>
 #include <QLabel>
 #include <QMenu>
-#include <QPainter>
 #include <QPointer>
 #include <QToolButton>
 #include <QWidgetAction>
@@ -37,9 +35,8 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Cambridge, MA 02110-1301, USA
 // KDE
 #include <KActionCollection>
 #include <KActionMenu>
-#include <KLocale>
-#include <KMenu>
-#include <KToolBar>
+#include <KLocalizedString>
+#include <KIconLoader>
 
 // Local
 #include "imagemetainfodialog.h"
@@ -131,7 +128,7 @@ struct FullScreenContentPrivate
     Document::Ptr mCurrentDocument;
     QPointer<ImageMetaInfoDialog> mImageMetaInfoDialog;
     QPointer<FullScreenConfigWidget> mConfigWidget;
-    KAction* mOptionsAction;
+    QAction * mOptionsAction;
 
     bool mFullScreenMode;
     bool mViewPageVisible;
@@ -147,9 +144,9 @@ struct FullScreenContentPrivate
         // menu should not be aligned to the right edge of the screen because
         // if the mode is changed to thumbnail-mode, we want the option button
         // to remain visible
-        mOptionsAction = new KAction(q);
+        mOptionsAction = new QAction(q);
         mOptionsAction->setPriority(QAction::LowPriority);
-        mOptionsAction->setIcon(KIcon("configure"));
+        mOptionsAction->setIcon(QIcon::fromTheme("configure"));
         mOptionsAction->setToolTip(i18nc("@info:tooltip", "Configure full screen mode"));
         QObject::connect(mOptionsAction, SIGNAL(triggered()), q, SLOT(showOptionsMenu()));
     }
@@ -321,7 +318,7 @@ ThumbnailBarView* FullScreenContent::thumbnailBar() const
     return d->mThumbnailBar;
 }
 
-void FullScreenContent::setCurrentUrl(const KUrl& url)
+void FullScreenContent::setCurrentUrl(const QUrl &url)
 {
     if (url.isEmpty()) {
         d->mCurrentDocument = Document::Ptr();
@@ -393,7 +390,7 @@ void FullScreenContent::showImageMetaInfoDialog()
 void FullScreenContent::slotPreferredMetaInfoKeyListChanged(const QStringList& list)
 {
     GwenviewConfig::setFullScreenPreferredMetaInfoKeyList(list);
-    GwenviewConfig::self()->writeConfig();
+    GwenviewConfig::self()->save();
     updateInformationLabel();
 }
 
@@ -481,14 +478,14 @@ void FullScreenContent::showOptionsMenu()
     QPoint pos;
     QWidget* button = d->mOptionsAction->associatedWidgets().first();
     Q_ASSERT(button);
-    kWarning() << button << button->geometry();
+    qWarning() << button << button->geometry();
     if (QApplication::isRightToLeft()) {
         pos = button->mapToGlobal(button->rect().bottomLeft());
     } else {
         pos = button->mapToGlobal(button->rect().bottomRight());
         pos.rx() -= menu.sizeHint().width();
     }
-    kWarning() << pos;
+    qWarning() << pos;
     menu.exec(pos);
 }
 
@@ -511,7 +508,7 @@ void FullScreenContent::slotImageMetaInfoDialogClosed()
 void FullScreenContent::slotShowThumbnailsToggled(bool value)
 {
     GwenviewConfig::setShowFullScreenThumbnails(value);
-    GwenviewConfig::self()->writeConfig();
+    GwenviewConfig::self()->save();
     d->mThumbnailBar->setVisible(value);
     d->updateLayout();
     d->mContent->adjustSize();
