@@ -52,7 +52,7 @@ Q_SIGNALS:
     void activated();
 
 protected:
-    bool eventFilter(QObject* object, QEvent* event);
+    bool eventFilter(QObject* object, QEvent* event) Q_DECL_OVERRIDE;
 
 private:
     DisabledActionShortcutMonitorPrivate* const d;
