@@ -24,6 +24,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Cambridge, MA 02110-1301, USA
 // Local
 
 // KDE
+#include <KIconLoader>
 #include <KPixmapSequence>
 
 // Qt
@@ -43,10 +44,10 @@ struct LoadingIndicatorPrivate
 
     LoadingIndicatorPrivate(LoadingIndicator* qq)
     : q(qq)
-    , mSequence("process-working", 22)
     , mIndex(0)
     , mTimer(new QTimer(qq))
     {
+        mSequence = KIconLoader::global()->loadPixmapSequence(QStringLiteral("process-working"), 22);
         mTimer->setInterval(100);
         QObject::connect(mTimer, SIGNAL(timeout()), q, SLOT(showNextFrame()));
     }
