@@ -42,8 +42,8 @@ public:
     RedEyeReductionImageOperation(const QRectF&);
     ~RedEyeReductionImageOperation();
 
-    virtual void redo();
-    virtual void undo();
+    virtual void redo() Q_DECL_OVERRIDE;
+    virtual void undo() Q_DECL_OVERRIDE;
 
     static void apply(QImage* img, const QRectF& rectF);
 
